/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal.handler;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.emfstore.client.model.WorkspaceManager;
import org.eclipse.emf.emfstore.common.model.Project;
import org.eclipse.jface.resource.ImageDescriptor;
import org.fortiss.tooling.kernel.ToolingKernelActivator;
import org.fortiss.tooling.kernel.base.HandlerBase;
import org.fortiss.tooling.kernel.interfaces.IHandler;
import org.fortiss.tooling.kernel.model.IProjectRootElement;

/**
 * {@link IHandler} for {@link Project}s.
 * 
 * @author hoelzlf
 * @author $Author$
 * @version $Rev$
 * @levd.rating RED Rev:
 */
public final class ProjectModelElementHandler extends HandlerBase<Project> {

	/** {@inheritDoc} */
	@Override
	public String getName(Project element) {
		return WorkspaceManager.getProjectSpace(element).getProjectName();
	}

	/** {@inheritDoc} */
	@Override
	public String getDescription(Project element) {
		return WorkspaceManager.getProjectSpace(element)
				.getProjectDescription();
	}

	/** {@inheritDoc} */
	@Override
	public ImageDescriptor getIconImageDescriptor() {
		return ToolingKernelActivator.getImageDescriptor("icons/project.png");
	}

	/** {@inheritDoc} */
	@Override
	public List<EObject> getSubnodes(Project element) {
		List<EObject> list = new ArrayList<EObject>();
		for (EObject node : element.getModelElements()) {
			if (node instanceof IProjectRootElement) {
				list.add(node);
			}
		}
		return list;
	}
}
