/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.internal.navigator;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.emfstore.client.model.ProjectSpace;
import org.eclipse.emf.emfstore.client.model.Workspace;
import org.eclipse.emf.emfstore.common.model.Project;
import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;
import org.fortiss.tooling.kernel.interfaces.IHandler;
import org.fortiss.tooling.kernel.services.IModelElementService;

/**
 * Content provider for the model navigator tree viewer.
 * 
 * @author hoelzlf
 * @author $Author$
 * @version $Rev$
 * @levd.rating RED Rev:
 */
public class NavigatorTreeContentProvider implements ITreeContentProvider {

	/** {@inheritDoc} */
	@Override
	public Object[] getElements(Object inputElement) {
		if (inputElement instanceof Workspace) {
			List<Project> result = new ArrayList<Project>();
			for (ProjectSpace space : ((Workspace) inputElement)
					.getProjectSpaces()) {
				result.add(space.getProject());
			}
			return result.toArray();
		}
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public Object[] getChildren(Object parentElement) {
		if (parentElement instanceof EObject) {
			IHandler<EObject> handler = IModelElementService.INSTANCE
					.getModelElementHandler((EObject) parentElement);
			if (handler != null) {
				return handler.getSubnodes((EObject) parentElement).toArray();
			}
		}
		return new Object[0];
	}

	/** {@inheritDoc} */
	@Override
	public Object getParent(Object element) {
		if (element instanceof EObject && !(element instanceof Workspace)) {
			return ((EObject) element).eContainer();
		}
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public boolean hasChildren(Object element) {
		return getChildren(element).length > 0;
	}

	/** {@inheritDoc} */
	@Override
	public void dispose() {
		// nothing to do
	}

	/** {@inheritDoc} */
	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
		// FIXME (FH): ignore?
	}
}
